import re

hth_keywords = ["华体会", "hth", "HTH"]
ky_keywords = ["开云"]
jy_keywords = ["九游"]


def read_file(filename):
    try:
        with open(filename, 'r') as file:
            return file.read()
    except IOError as e:
        print(f"Error reading file {filename}: {e}")
        raise


def write_file(filename, content):
    try:
        with open(filename, 'w') as file:
            file.write(content)
    except IOError as e:
        print(f"Error writing to file {filename}: {e}")
        raise


def replace_urls(js_content, url_mapping):
    for placeholder, url in url_mapping.items():
        js_content = js_content.replace(placeholder, url)
    return js_content


def get_url_mapping(urls_with_context, is_seo, template_type):
    # 初始化categories字典，区分SEO和非SEO模式
    if is_seo or template_type == 'ky' or template_type == 'jy':
        categories = {"WEB": [], "H5": [], "全站": [], "体育": [], "棋牌": [], "电子": []}
    else:  # 非SEO模式下的hth模板
        categories = {"web": [], "h5": [], "全站APP": [], "体育APP": []}

    # 遍历URLs及其前文本的元组列表进行分类
    for context, url in urls_with_context:
        key = context.strip().replace(" ", "")
        if key in categories:
            categories[key].append(url)

    # 构建映射字典，直接返回结果
    if template_type == 'hth':
        url_mapping = {
            "{{hthApp}}": categories.get("全站", [""])[0] if is_seo else categories.get("全站APP", [""])[0],
            "{{hthtyApp}}": categories.get("体育", [""])[0] if is_seo else categories.get("体育APP", [""])[0],
            "{{hthPc}}": categories.get("WEB", [""])[0] if is_seo else categories.get("web", [""])[0],
            "{{hthH5}}": categories.get("H5", [""])[0] if is_seo else categories.get("h5", [""])[0]
        }
    elif template_type == 'ky':  # ky模板
        url_mapping = {
            "{{kyPc1}}": categories.get("WEB", [""])[0],
            "{{kyPc2}}": categories.get("WEB", ["", ""])[1],
            "{{kyH51}}": categories.get("H5", [""])[0],
            "{{kyH52}}": categories.get("H5", ["", ""])[1],
            "{{kyApp1}}": categories.get("全站", [""])[0],
            "{{kyApp2}}": categories.get("体育", [""])[0],
            # "{{kyApp2}}": categories.get("全站", ["", ""])[1],
            "{{kyTy1}}": categories.get("体育", [""])[0],
            "{{kyTy2}}": categories.get("全站", [""])[0],
            # "{{kyTy2}}": categories.get("体育", ["", ""])[1]
        }
    elif template_type == 'jy':  # jy模板
        url_mapping = {
            "{{jyPc}}": categories.get("WEB", [""])[0],
            "{{jyH5}}": categories.get("H5", [""])[0],
            "{{jyApp}}": categories.get("全站", [""])[0],
            "{{jyQp}}": categories.get("棋牌", [""])[0],
            "{{jyDz}}": categories.get("电子", [""])[0],
            "{{jyFljPc}}": categories.get("WEB", [""])[1],
            "{{jyFljH5}}": categories.get("H5", [""])[1],
        }
    else:
        print('未知模板')
        return

    return url_mapping


def extract_urls(text):
    # seo_part_index = text.find("SEO 防拦截域名")
    # relevant_text = text[:seo_part_index] if seo_part_index != -1 else text
    pattern = r'(?:\n|^)\s*([^\n]*?)\s*(https?://[^\s]+)'
    matches = re.findall(pattern, text)
    return [(context.strip(), url) for context, url in matches]


def change_url(text, hth_template_path='/www/wwwroot/change_url/hth.js.template',
               ky_template_path='/www/wwwroot/change_url/ky.js.template',
               jy_template_path='/www/wwwroot/change_url/jy.js.template'):
    try:
        urls_with_context = extract_urls(text)
        expected_filename = None
        # 如果字符中有代理，则带后台链接
        if '代理WEB' in text or '代理web' in text:
            is_seo = False
        else:
            is_seo = True

        if any(keyword in text for keyword in hth_keywords) or not is_seo:
            template_path = hth_template_path
            template_type = 'hth'
        elif any(keyword in text for keyword in ky_keywords):
            template_path = ky_template_path
            template_type = 'ky'
        elif any(keyword in text for keyword in jy_keywords):
            template_path = jy_template_path
            template_type = 'jy'
        else:
            return False, 'unknown.js'

        js_content = read_file(template_path)
        url_mapping = get_url_mapping(urls_with_context, is_seo, template_type)
        updated_content = replace_urls(js_content, url_mapping)
        expected_filename = template_path.replace('.template', '')
        write_file(expected_filename, updated_content)

        return True, expected_filename
    except Exception as e:
        print(f"An error occurred: {e}")
        return False, expected_filename if expected_filename else 'unknown.js'

if __name__ == '__main__':
    text = '''SEO— 代理 专用域名

WEB     https://www.04qm83.vip:6004  
H5       https://www.17wq4x.vip:9520   【新】 
全站    https://www.abucqv.com:9519 【新】 
棋牌    https://www.2ghc85.vip:8004   【新】
电子    https://www.3mczux.vip:6001  【新】

九游娱乐【SEO防拦截域名】
WEB     https://www.9ji5rw.com:9519  
H5        https://www.9myqr9.com:9502'''
    change_url(text,hth_template_path='template/hth.js.template',ky_template_path='template/ky.js.template',jy_template_path='template/jy.js.template')